PORT_API_URL = 'https://api.getport.io'
PORT_API_US_URL = 'https://api.us.getport.io'
LOG_LEVEL = "DEBUG"

GENERIC_HEADERS = {
    'Content-Type': 'application/json',
    'Accept': 'application/json'
}
